/* Copyright (c) 2001 Ben Pfaff <pfaffben@msu.edu>.  All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are
   met:

     - Redistributions of source code must retain the above copyright
       notice, this list of conditions, and the following disclaimer.

     - Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions, and the following disclaimer in
       the documentation and/or other materials provided with the
       distribution.

   There is NO WARRANTY, not even for MERCHANTABILITY or FITNESS FOR A
   PARTICULAR PURPOSE.
*/

#include <stdio.h>
#include <stdlib.h>
#include "test.h"
#include "uniformity.h"

const char *pgm_name = "hull-test";

int
main (int argc, char *argv[])
{
  double *data;

  int n = 100;
  unsigned seed = time_seed ();
  
  if (argc <= 1)
    {
      printf ("usage: %s N [SEED], where:\n"
	      " N is the number of points in the test set (default 100)\n"
	      " SEED is the random seed (time-based default)\n",
	      argc > 0 && argv[0] != NULL ? argv[0] : "test");
      return EXIT_SUCCESS;
    }

  if (argc > 1)
    n = atoi (argv[1]);
  if (argc > 2)
    seed = atoi (argv[2]);
  srand (seed);

  data = malloc (sizeof *data * 2 * n);
  if (data == NULL)
    {
      printf ("memory allocation error\n");
      return EXIT_FAILURE;
    }

  printf ("newgraph\n");
  printf ("xaxis nodraw\n");
  printf ("yaxis nodraw\n");
  printf ("newline pts 0.1 0.1 0.5 0.5 0.9 0.1 0.1 0.1\n");

  {
    int i;
    
    for (i = 0; i < n; i++)
      {
	double x, y;
      
	do
	  {
	    x = data[i * 2] = (double) rand () / RAND_MAX;
	    y = data[i * 2 + 1] = (double) rand () / RAND_MAX;
	  }
	while (y > x || y > 1 - x || y < 0.1);

	printf ("newcurve marktype circle pts %g %g\n", x, y);
      }
  }
  
  {
    int i;

    for (i = 0; i < n; i++)
      {
	double test[2], tmp[4];

	do
	  {
	    test[0] = (double) rand () / RAND_MAX;
	    test[1] = (double) rand () / RAND_MAX;
	  }
	while (!unf_inside_hull (data, n, 2, test, tmp));
	
	printf ("newcurve marktype cross pts %g %g\n", test[0], test[1]);
      }
  }

  free (data);

  return EXIT_SUCCESS;
}
